==> monaco-vscode-debug-service-override-7.0.1.tgz: package/vscode/src/vs/workbench/contrib/debug/browser/replFilter.js <==
import { matchesFuzzy } from 'vscode/vscode/vs/base/common/filters';
import { splitGlobAware } from 'vscode/vscode/vs/base/common/glob';
import { TreeVisibility } from 'vscode/vscode/vs/base/browser/ui/tree/tree';
import { ReplEvaluationInput, ReplEvaluationResult } from 'vscode/vscode/vs/workbench/contrib/debug/common/replModel';
import { Variable } from 'vscode/vscode/vs/workbench/contrib/debug/common/debugModel';

class ReplFilter {
    constructor() {
        this._parsedQueries = [];
    }
    static { this.matchQuery = matchesFuzzy; }
    set filterQuery(query) {
        this._parsedQueries = [];
        query = query.trim();
        if (query && query !== '') {
            const filters = ( splitGlobAware(query, ',').map(s => s.trim())).filter(s => !!s.length);
            for (const f of filters) {
                if (f.startsWith('\\')) {
                    this._parsedQueries.push({ type: 'include', query: f.slice(1) });
                }
                else if (f.startsWith('!')) {
                    this._parsedQueries.push({ type: 'exclude', query: f.slice(1) });
                }
                else {
                    this._parsedQueries.push({ type: 'include', query: f });
                }
            }
        }
    }
    filter(element, parentVisibility) {
        if (element instanceof ReplEvaluationInput || element instanceof ReplEvaluationResult || element instanceof Variable) {
            return TreeVisibility.Visible;
        }
        let includeQueryPresent = false;
        let includeQueryMatched = false;
        const text = ( element.toString(true));
        for (const { type, query } of this._parsedQueries) {
            if (type === 'exclude' && ReplFilter.matchQuery(query, text)) {
                return false;
            }
            else if (type === 'include') {
                includeQueryPresent = true;
                if (ReplFilter.matchQuery(query, text)) {
                    includeQueryMatched = true;
                }
            }
        }
        return includeQueryPresent ? includeQueryMatched : (typeof parentVisibility !== 'undefined' ? parentVisibility : TreeVisibility.Visible);
    }
}

export { ReplFilter };

==> monaco-vscode-debug-service-override-10.1.1.tgz: package/vscode/src/vs/workbench/contrib/debug/browser/replFilter.js <==
import { matchesFuzzy } from 'vscode/vscode/vs/base/common/filters';
import { splitGlobAware } from 'vscode/vscode/vs/base/common/glob';
import { ReplEvaluationInput, ReplEvaluationResult } from 'vscode/vscode/vs/workbench/contrib/debug/common/replModel';
import { Variable } from 'vscode/vscode/vs/workbench/contrib/debug/common/debugModel';

class ReplFilter {
    constructor() {
        this._parsedQueries = [];
    }
    static { this.matchQuery = matchesFuzzy; }
    set filterQuery(query) {
        this._parsedQueries = [];
        query = query.trim();
        if (query && query !== '') {
            const filters = ( splitGlobAware(query, ',').map(s => s.trim())).filter(s => !!s.length);
            for (const f of filters) {
                if (f.startsWith('\\')) {
                    this._parsedQueries.push({ type: 'include', query: f.slice(1) });
                }
                else if (f.startsWith('!')) {
                    this._parsedQueries.push({ type: 'exclude', query: f.slice(1) });
                }
                else {
                    this._parsedQueries.push({ type: 'include', query: f });
                }
            }
        }
    }
    filter(element, parentVisibility) {
        if (element instanceof ReplEvaluationInput || element instanceof ReplEvaluationResult || element instanceof Variable) {
            return 1 ;
        }
        let includeQueryPresent = false;
        let includeQueryMatched = false;
        const text = ( element.toString(true));
        for (const { type, query } of this._parsedQueries) {
            if (type === 'exclude' && ReplFilter.matchQuery(query, text)) {
                return false;
            }
            else if (type === 'include') {
                includeQueryPresent = true;
                if (ReplFilter.matchQuery(query, text)) {
                    includeQueryMatched = true;
                }
            }
        }
        return includeQueryPresent ? includeQueryMatched : ((typeof parentVisibility !== 'undefined' ? parentVisibility : 1) );
    }
}

export { ReplFilter };
